@@ -1,15 +1,7 @@
-/***************************************************************************
-    copyright            : (C) 2008 by Carsten Niehaus
-    email                : cniehaus@kde.org
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Carsten Niehaus <cniehaus@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KALZIUM_PLASMA_H
 #define KALZIUM_PLASMA_H
