@@ -1,15 +1,7 @@
-/***************************************************************************
-    copyright            : (C) 2009 by Kashyap R Puranik
-    email                : kashthealien@gmail.com
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Kashyap R Puranik <kashthealien@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "nuclearCalculator.h"
 
