@@ -1,16 +1,8 @@
-/***************************************************************************
-    copyright            : (C) 2008, 2009 by Carsten Niehaus
-    email                : cniehaus@kde.org
-    Copyright 2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008, 2009 Carsten Niehaus <cniehaus@kde.org>
+    SPDX-FileCopyrightText: 2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kalzium_engine.h"
 
