@@ -1,17 +1,7 @@
-/***************************************************************************
-
-copyright            : (C) 2004, 2005, 2006, 2007 by Carsten Niehaus
-email                : cniehaus@kde.org
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004, 2005, 2006, 2007 Carsten Niehaus <cniehaus@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "detailedgraphicaloverview.h"
 
