@@ -1,16 +1,8 @@
-/***************************************************************************
-    copyright            : (C) 2004, 2005, 2006 by Carsten Niehaus
-    email                : cniehaus@kde.org
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004, 2005, 2006 Carsten Niehaus <cniehaus@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 #ifndef ELEMENTDATAVIEWER_H
 #define ELEMENTDATAVIEWER_H
 
