@@ -1,15 +1,7 @@
-/***************************************************************************
-    copyright            : (C) 2007 by Johannes Simon
-    email                : johannes.simon@gmail.com
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Johannes Simon <johannes.simon@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "exportdialog.h"
 
@@ -103,7 +95,7 @@ ExportDialog::ExportDialog(QWidget * parent)
     ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);
     qDebug() << "ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);";
 
-    setWindowTitle(i18n("Export Chemical Data"));
+    setWindowTitle(i18nc("@title:window", "Export Chemical Data"));
     qDebug() << "ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);";
 
     populateElementList();
