@@ -1,29 +1,13 @@
-/**********************************************************************
- PeriodicTableScene - Periodic Table Graphics Scene for Kalzium
+/*
+    PeriodicTableScene - Periodic Table Graphics Scene for Kalzium
 
- Copyright (C) 2005-2006 by Pino Toscano, toscano.pino@tiscali.it
- Copyright (C) 2003-2006 by Carsten Niehaus, cniehaus@kde.org
- Copyright (C) 2007-2009 by Marcus D. Hanwell, marcus@cryos.org
- Copyright (C) 2010 by Etienne Rebetez, etienne.rebetez@oberwallis.ch
+    SPDX-FileCopyrightText: 2005-2006 Pino Toscano <toscano.pino@tiscali.it>
+    SPDX-FileCopyrightText: 2003-2006 Carsten Niehaus <cniehaus@kde.org>
+    SPDX-FileCopyrightText: 2007-2009 Marcus D. Hanwell <marcus@cryos.org>
+    SPDX-FileCopyrightText: 2010 Etienne Rebetez <etienne.rebetez@oberwallis.ch>
 
- This file is part of the Kalzium molecular editor project.
-
- Kalzium is free software; you can redistribute it and/or modify
- it under the terms of the GNU Lesser General Public License as published by
- the Free Software Foundation; either version 2.1 of the License, or
- (at your option) any later version.
-
- Kalzium is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- 02110-1301, USA.
-
- **********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "periodictablescene.h"
 
